@@ -1,6 +1,6 @@
 package Data::Dumper::AutoEncode::AsDumper;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use strict; use warnings; use utf8;
 use Import::Into;
@@ -28,7 +28,7 @@ __END__
 
 =head1 VERSION
 
-version 1.0001
+version 1.0002
 
 =encoding utf8
 
@@ -117,9 +117,7 @@ Dai Okabayashi (L<BAYASHI|https://metacpan.org/author/BAYASHI>)
 
 Graham Knop (L<HAARG|https://metacpan.org/author/HAARG>)
 
-Gurusamy Sarathy (L<GSAR|https://metacpan.org/author/GSAR>)
-
-  ( and Sawyer X (L<XSAWYERX|https://metacpan.org/author/XSAWYERX>) )
+Gurusamy Sarathy (L<GSAR|https://metacpan.org/author/GSAR>) ( and Sawyer X (L<XSAWYERX|https://metacpan.org/author/XSAWYERX>) )
 
 Slaven Rezić (L<SREZIC|https://metacpan.org/author/SREZIC>)
 
